:status: under-construction

Hello, world!, context-agnostic
===============================

.. self-criticism::

   These docs are still under construction.

See the :si-icon:`octicons/mark-github-16` :github-tree:`full source code
<examples/hello_world_contexts>`.

.. code-block:: bash
   :caption: Invoke the script with ...

   python hello_world_contexts.py

.. literalinclude:: ../../../examples/hello_world_contexts/hello_world_contexts.py
   :caption:
   :pyobject: play_synths

.. literalinclude:: ../../../examples/hello_world_contexts/hello_world_contexts.py
   :caption:
   :pyobject: stop_synths

.. literalinclude:: ../../../examples/hello_world_contexts/hello_world_contexts.py
   :caption:
   :pyobject: run_threaded

.. literalinclude:: ../../../examples/hello_world_contexts/hello_world_contexts.py
   :caption:
   :pyobject: run_async

.. literalinclude:: ../../../examples/hello_world_contexts/hello_world_contexts.py
   :caption:
   :pyobject: run_nonrealtime

.. literalinclude:: ../../../examples/hello_world_contexts/hello_world_contexts.py
   :caption:
   :pyobject: parse_args

.. literalinclude:: ../../../examples/hello_world_contexts/hello_world_contexts.py
   :caption:
   :pyobject: main
